Python Client for Google Cloud Video Intelligence
=================================================

    Python idiomatic client for `Google Cloud Video Intelligence`_

.. _Google Cloud Video Intelligence: https://cloud.google.com/video-intelligence/

|pypi| |versions|

Quick Start
-----------

.. code-block:: console

    $ pip install --upgrade google-cloud-videointelligence

For more information on setting up your Python development environment,
such as installing ``pip`` and ``virtualenv`` on your system, please refer
to `Python Development Environment Setup Guide`_ for Google Cloud Platform.

.. _Python Development Environment Setup Guide: https://cloud.google.com/python/setup

Authentication
--------------

With ``google-cloud-python`` we try to make authentication as painless as
possible. Check out the `Authentication section`_ in our documentation to
learn more. You may also find the `authentication document`_ shared by all
the ``google-cloud-*`` libraries to be helpful.

.. _Authentication section: https://google-cloud-python.readthedocs.io/en/latest/core/auth.html
.. _authentication document: https://github.com/GoogleCloudPlatform/google-cloud-common/tree/master/authentication

Using the API
-------------

The Google Cloud `Video Intelligence`_ (`Video Intelligence API docs`_)
API enables developers to
understand the content of a video by encapsulating powerful machine
learning models in an easy to use REST API.

.. _Video Intelligence: https://cloud.google.com/video-intelligence/
.. _Video Intelligence API docs: https://cloud.google.com/video-intelligence/docs/reference/rest/

.. |pypi| image:: https://img.shields.io/pypi/v/google-cloud-videointelligence.svg
   :target: https://pypi.org/project/google-cloud-videointelligence/
.. |versions| image:: https://img.shields.io/pypi/pyversions/google-cloud-videointelligence.svg
   :target: https://pypi.org/project/google-cloud-videointelligence/
